@@ -17,6 +17,10 @@
    See the COPYING file for a copy of the GNU General Public License.
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "theme.h"
 #include "main.h"
 #include "tree.h"
@@ -549,28 +553,53 @@ static GdkPixbuf* preview_window(RrTheme *theme, const gchar *titlelayout,
             switch (*layout) {
             case 'D':
                 a = focus ?
+#if RR_CHECK_VERSION(3, 5, 28)
+                    theme->btn_desk->a_focused_unpressed :
+                    theme->btn_desk->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_desk :
                     theme->a_unfocused_unpressed_desk;
+#endif
                 break;
             case 'S':
                 a = focus ?
+#if RR_CHECK_VERSION(3, 5, 28)
+                    theme->btn_shade->a_focused_unpressed :
+                    theme->btn_shade->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_shade :
                     theme->a_unfocused_unpressed_shade;
+#endif
                 break;
             case 'I':
                 a = focus ?
+#if RR_CHECK_VERSION(3, 5, 28)
+                    theme->btn_iconify->a_focused_unpressed :
+                    theme->btn_iconify->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_iconify :
                     theme->a_unfocused_unpressed_iconify;
+#endif
                 break;
             case 'M':
                 a = focus ?
+#if RR_CHECK_VERSION(3, 5, 28)
+                    theme->btn_max->a_focused_unpressed :
+                    theme->btn_max->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_max :
                     theme->a_unfocused_unpressed_max;
+#endif
                 break;
             case 'C':
                 a = focus ?
+#if RR_CHECK_VERSION(3, 5, 28)
+                    theme->btn_close->a_focused_unpressed :
+                    theme->btn_close->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_close :
                     theme->a_unfocused_unpressed_close;
+#endif
                 break;
             default:
                 continue;
@@ -711,12 +740,15 @@ static GdkPixbuf* preview_window(RrTheme *theme, const gchar *titlelayout,
     w = width - 2*theme->fbwidth;
     h = theme->fbwidth;
 
-    scratch = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, w, h);
-    gdk_pixbuf_fill(scratch, rr_color_pixel(focus ?
-                                            theme->title_separator_focused_color :
-                                            theme->title_separator_unfocused_color));
+    if (h > 0)
+    {
+        scratch = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, w, h);
+        gdk_pixbuf_fill(scratch, rr_color_pixel(focus ?
+                                                theme->title_separator_focused_color :
+                                                theme->title_separator_unfocused_color));
 
-    gdk_pixbuf_copy_area(scratch, 0, 0, w, h, pixbuf, x, y);
+        gdk_pixbuf_copy_area(scratch, 0, 0, w, h, pixbuf, x, y);
+    }
 
     /* retarded way of adding client colour */
     x = theme->fbwidth;
